package de.jpainfo.model;

import java.text.DateFormat;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashSet;
import java.util.Set;

import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.OneToMany;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

@Entity
public class Kunde {
	
	private static final DateFormat format = new SimpleDateFormat("dd.MM.yyyy");
	
	@Id @GeneratedValue
	private Integer id;
	private String vorname;
	private String nachname;
	@Temporal(TemporalType.DATE)
	private Date geburtsdatum;
	private Anrede anrede;
	

	@OneToMany(mappedBy = "kunde")
	private Set<Verfuegung> verfuegungen;
	
	
	public Kunde() {
		verfuegungen = new HashSet<Verfuegung>();
	}
	
	
	public Kunde(String vorname, String nachname, String geburtsdatum, Anrede anrede) {
		this();
		this.vorname = vorname;
		this.nachname = nachname;
		this.anrede = anrede;
		try {
			this.geburtsdatum = format.parse(geburtsdatum);
		} catch (ParseException e) {
			throw new IllegalArgumentException("Falsches Datumsformat");
		}
	}
	
	
	public Verfuegung addKonto(String vonString, Konto konto) {
		Date von;
		try {
			von = format.parse(vonString);
		} catch (ParseException e) {
			throw new IllegalArgumentException("Falsches Datumsformat");
		}
		Verfuegung verfuegung = new Verfuegung(this, konto, von, null);
		this.getVerfuegungen().add(verfuegung);
		konto.getVerfuegungen().add(verfuegung);
		return verfuegung;
	}

	
	
	// Getter und Setter
	public Integer getId() {
		return id;
	}
	
	
	public String getVorname() {
		return vorname;
	}
	public void setVorname(String vorname) {
		this.vorname = vorname;
	}

	
	public String getNachname() {
		return nachname;
	}
	public void setNachname(String nachname) {
		this.nachname = nachname;
	}

	
	public Date getGeburtsdatum() {
		return geburtsdatum;
	}
	public void setGeburtsdatum(Date geburtsdatum) {
		this.geburtsdatum = geburtsdatum;
	}

	
	public Anrede getAnrede() {
		return anrede;
	}
	public void setAnrede(Anrede anrede) {
		this.anrede = anrede;
	}


	public Set<Verfuegung> getVerfuegungen() {
		return verfuegungen;
	}
	public void setVerfuegungen(Set<Verfuegung> verfuegungen) {
		this.verfuegungen = verfuegungen;
	}
	
	
}
